#! /bin/bash
# Script can be sourced or executed

function MakePackage(){
function _MakePackage(){
    ContentsDir="$1/$2"
    mkdir -v -p "$ContentsDir"
    mkdir -v  "$ContentsDir"/dox
    mkdir -v  "$ContentsDir"/cmake
    cat >"$ContentsDir"/README <<EOF
${1}
========
Purpose:
-------
DESCRIBE THE PURPOSE OF THE PACKAGE HERE

Contents:
--------
DECRIBE THE CONTENTS OF THE DIRECTORIES HERE.  EG:

### cmake
The cmake directory contains instructions for cmake on how to build and manage this package.

### dox
This directory contains inputs for doxygen that is used by the cometDoc package to produce documentation based on the code itself.

### configurations
This directory contains parameter files that control the behaviour of the package\'s executables at runtime (as opposed to compile constants).

### staticData
This directory contains static data such as calibration constants. 
It should NOT contain data produced by running the package, such as output oaEvent / root files.

### src
This directory contains the source code (probably c++, but could be python).

### scripts
This directory contains executable scripts (shell, python, perl etc).

### app
This directory contains code used to generate the packages executable.

Further documentation
--------------------
LIST HERE ANY OTHER DOCUMENTATION AND WHERE TO FIND IT (WEB, FILE ETC).
FILES SHOULD BE PUT IN THE PROJECT\'S TOP LEVEL documentation DIRECTORY.

EOF
}

PackageName="${1}"
Type="${2}"
Version="$3"
case "$Type" in
    low) 
    Prefix="oa"
    Name=$Prefix"$PackageName"
    _MakePackage "$Name" "$Version"
    mkdir -v $Name/$Version/src
    mkdir -v $Name/$Version/app
    mkdir -v $Name/$Version/scripts
    ;;
    high)
    Prefix="comet"
    Name=$Prefix"$PackageName"
    _MakePackage "$Name" "$Version"
    mkdir -v $Name/$Version/src
    mkdir -v $Name/$Version/app
    mkdir -v $Name/$Version/scripts
    mkdir -v $Name/$Version/configurations
    mkdir -v $Name/$Version/constants
    ;;
    framework)
    Prefix="frameworknameMgmt_"
    Name=$Prefix"$PackageName"
    _MakePackage "$Name" "$Version"
    mkdir -v $Name/$Version/src
    mkdir -v $Name/$Version/app
    mkdir -v $Name/$Version/scripts
    ;;
    meta)
    Prefix="FRAMEWORKNAME_"
    Name=$Prefix"$PackageName"
    _MakePackage "$Name" "$Version"
    ;;
    external)
    Prefix=""
    Name=$Prefix"$(echo $PackageName|tr 'a-z' 'A-Z')"
    _MakePackage "$Name" "$Version"
    touch "$Name/$Version/${PackageName}_$Version.tar.gz"
    ;;
    *)
    echo Error: Package type not recognised.
    echo USAGE: MakePackage PACKAGENAME TYPE VERSIONSTRING
    echo -e "\tTYPE must be one of 'low', 'high', 'framework', 'meta', 'external'"
    return -1
    ;;
esac
}

function MakeProject(){
if [ $# -gt 0 ];then
    ProjectName="${1}"
#    mkdir -v -p "${ProjectName}"/bin
#    echo This directory will contain soft links to the executables from the packages, to be placed by CMake after building. >>"${ProjectName}"/bin/README
    mkdir -v -p "${ProjectName}"/documentation/cometDocOutput
    echo Any formatted documentation '(ie. html or pdf)' should be stored here as well as the html documentation produced by the cometDoc package. >>"${ProjectName}"/documentation/README
    mkdir -v -p "${ProjectName}"/packages
    mkdir -v -p "${ProjectName}"/mgr
    echo This directory contains the necessary information for CMake to build and work with this project >>"${ProjectName}"/CMake/README
    touch "${ProjectName}"/mgr/CMakeList.txt
else
    echo I need the name of the Project
fi
}

function MakeExampleProject(){
    MakeProject exampleProject
    cd exampleProject/packages
    MakePackage VersionPolicy framework v3r1
    MakePackage LowLevel low v6r8p3
    MakePackage HighLevel high v3r1
    MakePackage AnExternal external v5r18p21n3
    MakePackage MetaPackage meta v10r1
    cd - >/dev/null
}

if [ `basename -- "$0"` == MakeFramework.sh ];then
    MakeExampleProject
fi
